@@ -90,6 +90,8 @@ enum eMFXHWType
     MFX_HW_BMG       = MFX_HW_MTL + 2,
     MFX_HW_LNL       = MFX_HW_MTL + 3,
 
+    MFX_HW_PTL       = 0x1800000,
+
 };
 
 enum eMFXGTConfig
@@ -578,6 +580,7 @@ typedef struct {
 
     /* ARL S */
     { 0x7D67, MFX_HW_ARL, MFX_GT2 },
+    { 0xB640, MFX_HW_ARL, MFX_GT2 },
 
     /* ARL H*/
     { 0x7D51, MFX_HW_ARL, MFX_GT2 },
@@ -589,7 +592,10 @@ typedef struct {
     { 0xE20B, MFX_HW_BMG, MFX_GT4 },
     { 0xE20C, MFX_HW_BMG, MFX_GT4 },
     { 0xE20D, MFX_HW_BMG, MFX_GT4 },
+    { 0xE210, MFX_HW_BMG, MFX_GT4 },
+    { 0xE211, MFX_HW_BMG, MFX_GT4 },
     { 0xE212, MFX_HW_BMG, MFX_GT4 },
+    { 0xE216, MFX_HW_BMG, MFX_GT4 },
 
     /* LNL */
     { 0x6420, MFX_HW_LNL, MFX_GT2 },
@@ -597,6 +603,16 @@ typedef struct {
     { 0x64A0, MFX_HW_LNL, MFX_GT2 },
     { 0x64B0, MFX_HW_LNL, MFX_GT2 },
 
+    /* PTL / Pantherlake */
+    { 0xB080, MFX_HW_PTL, MFX_GT2 },
+    { 0xB081, MFX_HW_PTL, MFX_GT2 },
+    { 0xB082, MFX_HW_PTL, MFX_GT2 },
+    { 0xB083, MFX_HW_PTL, MFX_GT2 },
+    { 0xB08F, MFX_HW_PTL, MFX_GT2 },
+    { 0xB090, MFX_HW_PTL, MFX_GT2 },
+    { 0xB0A0, MFX_HW_PTL, MFX_GT2 },
+    { 0xB0B0, MFX_HW_PTL, MFX_GT2 },
+
 };
 
 enum
